@@ -52,7 +52,7 @@ namespace Breeze
         // setup
         m_ui.setupUi( this );
 
-        connect( m_ui.buttonBox->button( QDialogButtonBox::Cancel ), SIGNAL(clicked()), this, SLOT(close()) );
+        connect( m_ui.buttonBox->button( QDialogButtonBox::Cancel ), &QAbstractButton::clicked, this, &QWidget::close );
         m_ui.windowClassCheckBox->setChecked( true );
 
 #if BREEZE_HAVE_X11
